const Parser = require('../../lib/parser');

describe('DynamoDB Record Parser', () => {
  describe('getIndiceNameName', () => {
    it('should parse "tableName"', () => {
      expect(Parser.getIndiceNameName({
        eventSourceARN: 'arn:aws:dynamodb:eu-west-1:345565672:table/here-is-table-name/stream/2018-05-04T11:52:38.373',
      })).toEqual('here-is-table-name');
    });

    it('should throw error if "eventSourceARN" in missing in the record', () => {
      expect(() => {
        Parser.getIndiceNameName({});
      }).toThrowErrorMatchingSnapshot();
    });

    it('should throw error if "eventSourceARN" is not DynamoDB ARN', () => {
      expect(() => {
        Parser.getIndiceNameName({
          eventSourceARN: 'arn:aws:s3:eu-west-1:345565672:table/here-is-table-name',
        });
      }).toThrowErrorMatchingSnapshot();
    });
  });

  describe('parseAction', () => {
    it('should parse "action" if it exist and supported', () => {
      expect(Parser.parseAction({
        eventName: 'INSERT',
      })).toEqual('INSERT');
    });

    it('should throw error if "action" is not supported', () => {
      expect(() => {
        Parser.parseAction({
          eventName: 'EDIT',
        });
      }).toThrowErrorMatchingSnapshot();
    });
  });

  describe('parseKeys', () => {
    it('should parse "keys"', () => {
      expect(Parser.parseKeys({
        dynamodb: {
          Keys: {
            primary_key: {
              S: '123',
            },
            sort_key: {
              N: 1,
            },
          },
        },
      })).toEqual({
        primary_key: '123',
        sort_key: 1,
      });
    });

    it('should throw error if "keys" is missing', () => {
      expect(() => {
        Parser.parseKeys({
          eventSourceARN: 'arn:aws:s3:eu-west-1:345565672:table/here-is-table-name',
        });
      }).toThrowErrorMatchingSnapshot();
    });
  });

  describe('parseData', () => {
    it('should parse "NewImage"', () => {
      expect(Parser.parseData({
        dynamodb: {
          NewImage: {
            primary_key: {
              S: '123',
            },
            sort_key: {
              N: 1,
            },
          },
        },
      })).toEqual({
        primary_key: '123',
        sort_key: 1,
      });
    });

    it('should parse "NewImage" as null is Action is REMOVE', () => {
      expect(Parser.parseData({}, 'REMOVE')).toEqual(null);
    });

    it('should throw error if "NewImage" is missing', () => {
      expect(() => {
        Parser.parseData({
          eventSourceARN: 'arn:aws:s3:eu-west-1:345565672:table/here-is-table-name',
        });
      }).toThrowErrorMatchingSnapshot();
    });
  });
});
