const AWS = require('aws-sdk');

AWS.config.region = process.env.ES_REGION;

const elasticsearch = require('elasticsearch');
const httpAwsEs = require('http-aws-es');

const es = elasticsearch.Client({
  hosts: [process.env.ES_ENDPOINT],
  connectionClass: httpAwsEs,
  amazonES: {
    region: process.env.ES_REGION,
  },
});

const isIndexExists = index => es.indices.exists({ index });

const createIndex = index => es.indices.create({ index });

const makeSureIndexIsOnPlace = (index, createIndexIfNeeded) => {
  if (!createIndexIfNeeded) {
    return Promise.resolve();
  }
  return isIndexExists(index).catch(() => createIndex(index));
};

const createHandlers = (index, type) => ({
  INSERT: (id, doc) => es.create({
    index,
    id,
    body: doc,
    type,
  }),
  MODIFY: (id, doc) => es.update({
    index,
    id,
    body: {
      doc,
    },
    type,
  }),
  REMOVE: id => es.delete({
    index,
    id,
    type,
  }),
});

module.exports = ({
  index,
  type,
  createIndexIfNeeded,
}) => makeSureIndexIsOnPlace(index, createIndexIfNeeded)
  .then(() => createHandlers(index, type));
